# CLI Reference

This is an automatically generated api doc of the flags and arguments that can be passed to conda-lock
and its various subcommands.

::: mkdocs-click
    :module: conda_lock.conda_lock
    :command: main
    :prog_name: conda-lock
    :style: table
    :depth: 1
